summaryrefslogtreecommitdiffstats
path: root/kplato/kptdatetime.h
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptdatetime.h')
-rw-r--r--kplato/kptdatetime.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kplato/kptdatetime.h b/kplato/kptdatetime.h
index cb682c13..beef4858 100644
--- a/kplato/kptdatetime.h
+++ b/kplato/kptdatetime.h
@@ -19,7 +19,7 @@
#ifndef KPTDATETIME_H
#define KPTDATETIME_H
-#include <qdatetime.h>
+#include <tqdatetime.h>
#include "kptduration.h"
namespace KPlato
@@ -28,14 +28,14 @@ namespace KPlato
class Duration;
/**
* DateTime is a @ref QDateTime which knows about @ref Duration
*/
-class DateTime : public QDateTime {
+class DateTime : public TQDateTime {
public:
DateTime();
- DateTime(const QDateTime &dt);
- DateTime(const QDate &date, const QTime &time);
+ DateTime(const TQDateTime &dt);
+ DateTime(const TQDate &date, const TQTime &time);
/**
* Adds the duration @param duration to the datetime
@@ -54,14 +54,14 @@ public:
DateTime &operator+=(const Duration &duration);
DateTime &operator-=(const Duration &duration);
- static DateTime fromString(const QString dts) {
- QDateTime dt;
+ static DateTime fromString(const TQString dts) {
+ TQDateTime dt;
if (dts.isEmpty())
return DateTime();
- dt = QDateTime::fromString(dts, Qt::ISODate);
+ dt = TQDateTime::fromString(dts, Qt::ISODate);
if (dt.isValid())
return DateTime(dt);
- return DateTime(QDateTime::fromString(dts));
+ return DateTime(TQDateTime::fromString(dts));
}
private:
@@ -28,14 +28,14 @@ namespace KPlato
class Duration;
/**
- * DateTime is a @ref QDateTime which knows about @ref Duration
+ * DateTime is a @ref TQDateTime which knows about @ref Duration
*/